@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -66,10 +66,11 @@ typedef struct _so {
 	bool msg_in_msg;
 	bool headers_only;
 	bool add_received_date;
-	bool force_tnef;
+	int use_tnef;					// -1: minimize usage, 0: autodetect, 1: force
 	bool force_utf8;
 	char *charset_upgrade;
 	bool allow_send_to_everyone;
+	bool enable_dsn;				/**< Enable SMTP Delivery Status Notifications */
 } sending_options;
 
 void INETMAPI_API imopt_default_delivery_options(delivery_options *dopt);
