@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -75,7 +75,7 @@ public:
 	HRESULT HrEnableTLS();
 
 	HRESULT HrGets(char *szBuffer, ULONG ulBufSize, ULONG *lpulRead);
-	HRESULT HrReadLine(std::string * strBuffer);
+	HRESULT HrReadLine(std::string * strBuffer, ULONG ulMaxBuffer = 65536);
 	HRESULT HrWriteString(char * szBuffer);
 	HRESULT HrWriteString(const std::string & strBuffer);
 	HRESULT HrWriteLine(char *szBuffer, int len = 0);
@@ -87,7 +87,7 @@ public:
 	HRESULT HrSelect(int seconds);
 
 	void SetIPAddress(char *szIPAddress);
-	std::string GetIPAddress();
+	const std::string& GetIPAddress() const;
 		
 	bool UsingSsl();
 	bool sslctx();
