@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -284,6 +284,14 @@ public:
 		return helpers::convert_from(RowSetToString(lpRowSet));
 	}
 
+	static string_type toString(LPROWLIST lpRowList) {
+		return helpers::convert_from(RowListToString(lpRowList));
+	}
+
+	static string_type toString(LPACTION lpAction) {
+		return helpers::convert_from(ActionToString(lpAction));
+	}
+
 	static string_type toString(LPSPropProblemArray lpPropblemArray) {
 		return helpers::convert_from(ProblemArrayToString(lpPropblemArray));
 	}
