@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -70,6 +70,18 @@
 #define EC_LOGLEVEL_INFO	5
 #define EC_LOGLEVEL_DEBUG	6
 
+#define EC_LOGLEVEL_MASK	0xF
+
+#define EC_LOGLEVEL_EXTENDED_MASK 0xFFFF0000
+
+// Zarafa-server extended log options
+#define EC_LOGLEVEL_SQL			0x00010000
+#define EC_LOGLEVEL_PLUGIN		0x00020000
+#define EC_LOGLEVEL_CACHE		0x00040000
+#define EC_LOGLEVEL_USERCACHE	0x00080000
+#define EC_LOGLEVEL_SOAP		0x00100000
+#define EC_LOGLEVEL_ICS			0x00200000
+
 #define _LOG_BUFSIZE		10240
 #define _LOG_TSSIZE			64
 
@@ -115,6 +127,7 @@ protected:
 	pthread_mutex_t msgbuflock;
 #ifndef __OpenBSD__
 	locale_t timelocale;
+	locale_t datalocale;
 #endif
 	char timestring[_LOG_TSSIZE];
 	logprefix prefix;
@@ -163,6 +176,11 @@ public:
 	 * references are removed.
 	 */
 	unsigned Release();
+	/**
+	 * Like the CRT snprintf, but uses the datalocale used by the current
+	 * ECLogger instance.
+	 */
+	int snprintf(char *str, size_t size, const char *format, ...) __LIKE_PRINTF(4, 5);
 	/**
 	 * Used for log rotation. Implementations should prepare to log in a new log.
 	 *
