@@ -99,6 +99,12 @@
 #define PR_ZC_CONTACT_FOLDER_NAMES_A	PROP_TAG(PT_MV_STRING8, PR_EC_BASE+0x13)
 #define PR_ZC_CONTACT_FOLDER_NAMES_W	PROP_TAG(PT_MV_UNICODE, PR_EC_BASE+0x13)
 
+#define PR_ZC_ORIGINAL_ENTRYID				PROP_TAG(PT_BINARY,	PR_EC_BASE+0x20)
+#define PR_ZC_ORIGINAL_PARENT_ENTRYID		PROP_TAG(PT_BINARY,	PR_EC_BASE+0x21)
+#define PR_ZC_ORIGINAL_SOURCE_KEY			PROP_TAG(PT_BINARY,	PR_EC_BASE+0x22)
+#define PR_ZC_ORIGINAL_PARENT_SOURCE_KEY	PROP_TAG(PT_BINARY,	PR_EC_BASE+0x23)
+#define PR_ZC_ORIGINAL_CHANGE_KEY			PROP_TAG(PT_BINARY,	PR_EC_BASE+0x24)
+
 ////////////////////////////////////////////////////////////////////////////////
 
 // The property under which we actually save the PR_ENTRYID in recipient tables
