@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 - 2012  Zarafa B.V.
+ * Copyright 2005 - 2013  Zarafa B.V.
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
@@ -56,6 +56,7 @@
 #include "mapi_ptr/mapi_rowset_ptr.h"
 
 #include <mapix.h>
+#include <mapispi.h>
 #include <edkmdb.h>
 #include <edkguid.h>
 
@@ -63,6 +64,7 @@
 #include "IECSecurity.h"
 #include "IECSingleInstance.h"
 #include "ECGuid.h"
+#include "mapiguidext.h"
 
 DEFINEMAPIPTR(ABContainer);
 DEFINEMAPIPTR(AddrBook);
@@ -72,6 +74,7 @@ DEFINEMAPIPTR(ECServiceAdmin);
 DEFINEMAPIPTR(ECSingleInstance);
 DEFINEMAPIPTR(ExchangeManageStore);
 DEFINEMAPIPTR(ExchangeModifyTable);
+DEFINEMAPIPTR(ExchangeExportChanges);
 DEFINEMAPIPTR(MAPIAdviseSink);
 DEFINEMAPIPTR(MAPIContainer);
 DEFINEMAPIPTR(MAPIFolder);
@@ -88,6 +91,7 @@ DEFINEMAPIPTR(ProviderAdmin);
 DEFINEMAPIPTR(Unknown);
 DEFINEMAPIPTR(Stream);
 typedef mapi_object_ptr<IAttach, IID_IAttachment> AttachPtr;	// Nice... MS (not Mark S) is a bit inconsistent here.
+DEFINEMAPIPTR(MAPIGetSession);
 
 
 typedef mapi_memory_ptr<ECPERMISSION> ECPermissionPtr;
@@ -100,9 +104,13 @@ typedef mapi_memory_ptr<SPropTagArray> SPropTagArrayPtr;
 typedef mapi_memory_ptr<SRestriction> SRestrictionPtr;
 typedef mapi_memory_ptr<SSortOrderSet> SSortOrderSetPtr;
 typedef mapi_memory_ptr<WCHAR> WStringPtr;
+typedef mapi_memory_ptr<FlagList> FlagListPtr;
 
 typedef mapi_array_ptr<ECPERMISSION> ECPermissionArrayPtr;
 typedef mapi_array_ptr<SPropValue> SPropArrayPtr;
 
+typedef mapi_rowset_ptr<SRow> SRowSetPtr;
+typedef mapi_rowset_ptr<ADRENTRY> AdrListPtr;
+
 
 #endif // ndef mapi_ptr_INCLUDED
