@@ -1384,6 +1384,12 @@ PR_ZC_CONTACT_FOLDER_NAMES =	PROP_TAG(PT_MV_TSTRING, PR_EC_BASE + 0x13)
 PR_ZC_CONTACT_FOLDER_NAMES_A =	PROP_TAG(PT_MV_STRING8, PR_EC_BASE + 0x13)
 PR_ZC_CONTACT_FOLDER_NAMES_W =	PROP_TAG(PT_MV_UNICODE, PR_EC_BASE + 0x13)
 
+PR_ZC_ORIGINAL_ENTRYID				= PROP_TAG(PT_BINARY,	PR_EC_BASE+0x20)
+PR_ZC_ORIGINAL_PARENT_ENTRYID		= PROP_TAG(PT_BINARY,	PR_EC_BASE+0x21)
+PR_ZC_ORIGINAL_SOURCE_KEY			= PROP_TAG(PT_BINARY,	PR_EC_BASE+0x22)
+PR_ZC_ORIGINAL_PARENT_SOURCE_KEY	= PROP_TAG(PT_BINARY,	PR_EC_BASE+0x23)
+PR_ZC_ORIGINAL_CHANGE_KEY			= PROP_TAG(PT_BINARY,	PR_EC_BASE+0x24)
+
 PR_EC_CHANGE_ADVISOR	= PROP_TAG(PT_OBJECT, PR_EC_BASE+0x89)
 
 PR_EC_STATSTABLE_SYSTEM		= PROP_TAG(PT_OBJECT,		PR_EC_BASE+0x30)
